==> gegl-0.4.6.tar.bz2: gegl-0.4.6/operations/common/module.c <==
#include "config.h"
#include <gegl-plugin.h>
void gegl_op_absolute_register_type(GTypeModule *module);
void gegl_op_alien_map_register_type(GTypeModule *module);
void gegl_op_bilateral_filter_register_type(GTypeModule *module);
void gegl_op_box_blur_register_type(GTypeModule *module);
void gegl_op_brightness_contrast_register_type(GTypeModule *module);
void gegl_op_buffer_sink_register_type(GTypeModule *module);
void gegl_op_buffer_source_register_type(GTypeModule *module);
void gegl_op_c2g_register_type(GTypeModule *module);
void gegl_op_checkerboard_register_type(GTypeModule *module);
void gegl_op_dither_register_type(GTypeModule *module);
void gegl_op_color_enhance_register_type(GTypeModule *module);
void gegl_op_color_overlay_register_type(GTypeModule *module);
void gegl_op_color_rotate_register_type(GTypeModule *module);
void gegl_op_color_temperature_register_type(GTypeModule *module);
void gegl_op_color_warp_register_type(GTypeModule *module);
void gegl_op_color_register_type(GTypeModule *module);
void gegl_op_component_extract_register_type(GTypeModule *module);
void gegl_op_contrast_curve_register_type(GTypeModule *module);
void gegl_op_convolution_matrix_register_type(GTypeModule *module);
void gegl_op_copy_buffer_register_type(GTypeModule *module);
void gegl_op_difference_of_gaussians_register_type(GTypeModule *module);
void gegl_op_display_register_type(GTypeModule *module);
void gegl_op_distance_transform_register_type(GTypeModule *module);
void gegl_op_dropshadow_register_type(GTypeModule *module);
void gegl_op_edge_neon_register_type(GTypeModule *module);
void gegl_op_edge_sobel_register_type(GTypeModule *module);
void gegl_op_exp_combine_register_type(GTypeModule *module);
void gegl_op_exposure_register_type(GTypeModule *module);
void gegl_op_fattal02_register_type(GTypeModule *module);
void gegl_op_gaussian_blur_register_type(GTypeModule *module);
void gegl_op_gblur_1d_register_type(GTypeModule *module);
void gegl_op_gegl_buffer_load_op_register_type(GTypeModule *module);
void gegl_op_gegl_buffer_save_op_register_type(GTypeModule *module);
void gegl_op_gegl_register_type(GTypeModule *module);
void gegl_op_grey_register_type(GTypeModule *module);
void gegl_op_grid_register_type(GTypeModule *module);
void gegl_op_high_pass_register_type(GTypeModule *module);
void gegl_op_hue_chroma_register_type(GTypeModule *module);
void gegl_op_icc_save_register_type(GTypeModule *module);
void gegl_op_image_compare_register_type(GTypeModule *module);
void gegl_op_image_gradient_register_type(GTypeModule *module);
void gegl_op_introspect_register_type(GTypeModule *module);
void gegl_op_invert_gamma_register_type(GTypeModule *module);
void gegl_op_invert_linear_register_type(GTypeModule *module);
void gegl_op_layer_register_type(GTypeModule *module);
void gegl_op_levels_register_type(GTypeModule *module);
void gegl_op_linear_gradient_register_type(GTypeModule *module);
void gegl_op_little_planet_register_type(GTypeModule *module);
void gegl_op_magick_load_register_type(GTypeModule *module);
void gegl_op_mantiuk06_register_type(GTypeModule *module);
void gegl_op_map_absolute_register_type(GTypeModule *module);
void gegl_op_map_relative_register_type(GTypeModule *module);
void gegl_op_matting_global_register_type(GTypeModule *module);
void gegl_op_mblur_register_type(GTypeModule *module);
void gegl_op_mean_curvature_blur_register_type(GTypeModule *module);
void gegl_op_median_blur_register_type(GTypeModule *module);
void gegl_op_mirrors_register_type(GTypeModule *module);
void gegl_op_mix_register_type(GTypeModule *module);
void gegl_op_mono_mixer_register_type(GTypeModule *module);
void gegl_op_motion_blur_linear_register_type(GTypeModule *module);
void gegl_op_newsprint_register_type(GTypeModule *module);
void gegl_op_noise_cie_lch_register_type(GTypeModule *module);
void gegl_op_noise_hsv_register_type(GTypeModule *module);
void gegl_op_noise_hurl_register_type(GTypeModule *module);
void gegl_op_noise_perlin_register_type(GTypeModule *module);
void gegl_op_noise_pick_register_type(GTypeModule *module);
void gegl_op_noise_reduction_register_type(GTypeModule *module);
void gegl_op_noise_rgb_register_type(GTypeModule *module);
void gegl_op_noise_simplex_register_type(GTypeModule *module);
void gegl_op_noise_spread_register_type(GTypeModule *module);
void gegl_op_noise_cell_register_type(GTypeModule *module);
void gegl_op_opacity_register_type(GTypeModule *module);
void gegl_op_open_buffer_register_type(GTypeModule *module);
void gegl_op_over_register_type(GTypeModule *module);
void gegl_op_panorama_projection_register_type(GTypeModule *module);
void gegl_op_pixelize_register_type(GTypeModule *module);
void gegl_op_posterize_register_type(GTypeModule *module);
void gegl_op_radial_gradient_register_type(GTypeModule *module);
void gegl_op_rectangle_register_type(GTypeModule *module);
void gegl_op_recursive_transform_register_type(GTypeModule *module);
void gegl_op_reinhard05_register_type(GTypeModule *module);
void gegl_op_remap_register_type(GTypeModule *module);
void gegl_op_rgb_clip_register_type(GTypeModule *module);
void gegl_op_saturation_register_type(GTypeModule *module);
void gegl_op_save_register_type(GTypeModule *module);
void gegl_op_sepia_register_type(GTypeModule *module);
void gegl_op_slic_register_type(GTypeModule *module);
void gegl_op_snn_mean_register_type(GTypeModule *module);
void gegl_op_spherize_register_type(GTypeModule *module);
void gegl_op_stress_register_type(GTypeModule *module);
void gegl_op_stretch_contrast_hsv_register_type(GTypeModule *module);
void gegl_op_stretch_contrast_register_type(GTypeModule *module);
void gegl_op_svg_huerotate_register_type(GTypeModule *module);
void gegl_op_svg_luminancetoalpha_register_type(GTypeModule *module);
void gegl_op_svg_matrix_register_type(GTypeModule *module);
void gegl_op_svg_saturate_register_type(GTypeModule *module);
void gegl_op_threshold_register_type(GTypeModule *module);
void gegl_op_tile_register_type(GTypeModule *module);
void gegl_op_tile_seamless_register_type(GTypeModule *module);
void gegl_op_unsharp_mask_register_type(GTypeModule *module);
void gegl_op_unpremultiply_register_type(GTypeModule *module);
void gegl_op_value_invert_register_type(GTypeModule *module);
void gegl_op_vignette_register_type(GTypeModule *module);
void gegl_op_warp_register_type(GTypeModule *module);
void gegl_op_waterpixels_register_type(GTypeModule *module);
void gegl_op_watershed_transform_register_type(GTypeModule *module);
void gegl_op_wavelet_blur_1d_register_type(GTypeModule *module);
void gegl_op_wavelet_blur_register_type(GTypeModule *module);
void gegl_op_weighted_blend_register_type(GTypeModule *module);
void gegl_op_write_buffer_register_type(GTypeModule *module);
static const GeglModuleInfo modinfo = {
GEGL_MODULE_ABI_VERSION
};

const GeglModuleInfo * gegl_module_query (GTypeModule *module);
gboolean gegl_module_register (GTypeModule *module);

G_MODULE_EXPORT const GeglModuleInfo *
gegl_module_query (GTypeModule *module)
{
  return &modinfo;
}

G_MODULE_EXPORT gboolean
gegl_module_register (GTypeModule *module)
{
  gegl_op_absolute_register_type(module);
  gegl_op_alien_map_register_type(module);
  gegl_op_bilateral_filter_register_type(module);
  gegl_op_box_blur_register_type(module);
  gegl_op_brightness_contrast_register_type(module);
  gegl_op_buffer_sink_register_type(module);
  gegl_op_buffer_source_register_type(module);
  gegl_op_c2g_register_type(module);
  gegl_op_checkerboard_register_type(module);
  gegl_op_dither_register_type(module);
  gegl_op_color_enhance_register_type(module);
  gegl_op_color_overlay_register_type(module);
  gegl_op_color_rotate_register_type(module);
  gegl_op_color_temperature_register_type(module);
  gegl_op_color_warp_register_type(module);
  gegl_op_color_register_type(module);
  gegl_op_component_extract_register_type(module);
  gegl_op_contrast_curve_register_type(module);
  gegl_op_convolution_matrix_register_type(module);
  gegl_op_copy_buffer_register_type(module);
  gegl_op_difference_of_gaussians_register_type(module);
  gegl_op_display_register_type(module);
  gegl_op_distance_transform_register_type(module);
  gegl_op_dropshadow_register_type(module);
  gegl_op_edge_neon_register_type(module);
  gegl_op_edge_sobel_register_type(module);
  gegl_op_exp_combine_register_type(module);
  gegl_op_exposure_register_type(module);
  gegl_op_fattal02_register_type(module);
  gegl_op_gaussian_blur_register_type(module);
  gegl_op_gblur_1d_register_type(module);
  gegl_op_gegl_buffer_load_op_register_type(module);
  gegl_op_gegl_buffer_save_op_register_type(module);
  gegl_op_gegl_register_type(module);
  gegl_op_grey_register_type(module);
  gegl_op_grid_register_type(module);
  gegl_op_high_pass_register_type(module);
  gegl_op_hue_chroma_register_type(module);
  gegl_op_icc_save_register_type(module);
  gegl_op_image_compare_register_type(module);
  gegl_op_image_gradient_register_type(module);
  gegl_op_introspect_register_type(module);
  gegl_op_invert_gamma_register_type(module);
  gegl_op_invert_linear_register_type(module);
  gegl_op_layer_register_type(module);
  gegl_op_levels_register_type(module);
  gegl_op_linear_gradient_register_type(module);
  gegl_op_little_planet_register_type(module);
  gegl_op_magick_load_register_type(module);
  gegl_op_mantiuk06_register_type(module);
  gegl_op_map_absolute_register_type(module);
  gegl_op_map_relative_register_type(module);
  gegl_op_matting_global_register_type(module);
  gegl_op_mblur_register_type(module);
  gegl_op_mean_curvature_blur_register_type(module);
  gegl_op_median_blur_register_type(module);
  gegl_op_mirrors_register_type(module);
  gegl_op_mix_register_type(module);
  gegl_op_mono_mixer_register_type(module);
  gegl_op_motion_blur_linear_register_type(module);
  gegl_op_newsprint_register_type(module);
  gegl_op_noise_cie_lch_register_type(module);
  gegl_op_noise_hsv_register_type(module);
  gegl_op_noise_hurl_register_type(module);
  gegl_op_noise_perlin_register_type(module);
  gegl_op_noise_pick_register_type(module);
  gegl_op_noise_reduction_register_type(module);
  gegl_op_noise_rgb_register_type(module);
  gegl_op_noise_simplex_register_type(module);
  gegl_op_noise_spread_register_type(module);
  gegl_op_noise_cell_register_type(module);
  gegl_op_opacity_register_type(module);
  gegl_op_open_buffer_register_type(module);
  gegl_op_over_register_type(module);
  gegl_op_panorama_projection_register_type(module);
  gegl_op_pixelize_register_type(module);
  gegl_op_posterize_register_type(module);
  gegl_op_radial_gradient_register_type(module);
  gegl_op_rectangle_register_type(module);
  gegl_op_recursive_transform_register_type(module);
  gegl_op_reinhard05_register_type(module);
  gegl_op_remap_register_type(module);
  gegl_op_rgb_clip_register_type(module);
  gegl_op_saturation_register_type(module);
  gegl_op_save_register_type(module);
  gegl_op_sepia_register_type(module);
  gegl_op_slic_register_type(module);
  gegl_op_snn_mean_register_type(module);
  gegl_op_spherize_register_type(module);
  gegl_op_stress_register_type(module);
  gegl_op_stretch_contrast_hsv_register_type(module);
  gegl_op_stretch_contrast_register_type(module);
  gegl_op_svg_huerotate_register_type(module);
  gegl_op_svg_luminancetoalpha_register_type(module);
  gegl_op_svg_matrix_register_type(module);
  gegl_op_svg_saturate_register_type(module);
  gegl_op_threshold_register_type(module);
  gegl_op_tile_register_type(module);
  gegl_op_tile_seamless_register_type(module);
  gegl_op_unsharp_mask_register_type(module);
  gegl_op_unpremultiply_register_type(module);
  gegl_op_value_invert_register_type(module);
  gegl_op_vignette_register_type(module);
  gegl_op_warp_register_type(module);
  gegl_op_waterpixels_register_type(module);
  gegl_op_watershed_transform_register_type(module);
  gegl_op_wavelet_blur_1d_register_type(module);
  gegl_op_wavelet_blur_register_type(module);
  gegl_op_weighted_blend_register_type(module);
  gegl_op_write_buffer_register_type(module);
 return TRUE;
}

==> gegl-0.4.12.tar.bz2: gegl-0.4.12/operations/common/module.c <==
#include "config.h"
#include <gegl-plugin.h>
void gegl_op_absolute_register_type(GTypeModule *module);
void gegl_op_alien_map_register_type(GTypeModule *module);
void gegl_op_bilateral_filter_register_type(GTypeModule *module);
void gegl_op_box_blur_register_type(GTypeModule *module);
void gegl_op_brightness_contrast_register_type(GTypeModule *module);
void gegl_op_buffer_sink_register_type(GTypeModule *module);
void gegl_op_buffer_source_register_type(GTypeModule *module);
void gegl_op_c2g_register_type(GTypeModule *module);
void gegl_op_checkerboard_register_type(GTypeModule *module);
void gegl_op_dither_register_type(GTypeModule *module);
void gegl_op_color_enhance_register_type(GTypeModule *module);
void gegl_op_color_overlay_register_type(GTypeModule *module);
void gegl_op_color_rotate_register_type(GTypeModule *module);
void gegl_op_color_temperature_register_type(GTypeModule *module);
void gegl_op_color_warp_register_type(GTypeModule *module);
void gegl_op_color_register_type(GTypeModule *module);
void gegl_op_component_extract_register_type(GTypeModule *module);
void gegl_op_contrast_curve_register_type(GTypeModule *module);
void gegl_op_convolution_matrix_register_type(GTypeModule *module);
void gegl_op_copy_buffer_register_type(GTypeModule *module);
void gegl_op_difference_of_gaussians_register_type(GTypeModule *module);
void gegl_op_display_register_type(GTypeModule *module);
void gegl_op_distance_transform_register_type(GTypeModule *module);
void gegl_op_dropshadow_register_type(GTypeModule *module);
void gegl_op_edge_neon_register_type(GTypeModule *module);
void gegl_op_edge_sobel_register_type(GTypeModule *module);
void gegl_op_exp_combine_register_type(GTypeModule *module);
void gegl_op_exposure_register_type(GTypeModule *module);
void gegl_op_fattal02_register_type(GTypeModule *module);
void gegl_op_gaussian_blur_register_type(GTypeModule *module);
void gegl_op_gblur_1d_register_type(GTypeModule *module);
void gegl_op_gegl_buffer_load_op_register_type(GTypeModule *module);
void gegl_op_gegl_buffer_save_op_register_type(GTypeModule *module);
void gegl_op_gegl_register_type(GTypeModule *module);
void gegl_op_grey_register_type(GTypeModule *module);
void gegl_op_grid_register_type(GTypeModule *module);
void gegl_op_high_pass_register_type(GTypeModule *module);
void gegl_op_hue_chroma_register_type(GTypeModule *module);
void gegl_op_icc_save_register_type(GTypeModule *module);
void gegl_op_image_compare_register_type(GTypeModule *module);
void gegl_op_image_gradient_register_type(GTypeModule *module);
void gegl_op_introspect_register_type(GTypeModule *module);
void gegl_op_invert_gamma_register_type(GTypeModule *module);
void gegl_op_invert_linear_register_type(GTypeModule *module);
void gegl_op_layer_register_type(GTypeModule *module);
void gegl_op_levels_register_type(GTypeModule *module);
void gegl_op_linear_gradient_register_type(GTypeModule *module);
void gegl_op_little_planet_register_type(GTypeModule *module);
void gegl_op_long_shadow_register_type(GTypeModule *module);
void gegl_op_magick_load_register_type(GTypeModule *module);
void gegl_op_mantiuk06_register_type(GTypeModule *module);
void gegl_op_map_absolute_register_type(GTypeModule *module);
void gegl_op_map_relative_register_type(GTypeModule *module);
void gegl_op_matting_global_register_type(GTypeModule *module);
void gegl_op_mblur_register_type(GTypeModule *module);
void gegl_op_mean_curvature_blur_register_type(GTypeModule *module);
void gegl_op_median_blur_register_type(GTypeModule *module);
void gegl_op_mirrors_register_type(GTypeModule *module);
void gegl_op_mix_register_type(GTypeModule *module);
void gegl_op_mono_mixer_register_type(GTypeModule *module);
void gegl_op_motion_blur_linear_register_type(GTypeModule *module);
void gegl_op_newsprint_register_type(GTypeModule *module);
void gegl_op_noise_cie_lch_register_type(GTypeModule *module);
void gegl_op_noise_hsv_register_type(GTypeModule *module);
void gegl_op_noise_hurl_register_type(GTypeModule *module);
void gegl_op_noise_perlin_register_type(GTypeModule *module);
void gegl_op_noise_pick_register_type(GTypeModule *module);
void gegl_op_noise_reduction_register_type(GTypeModule *module);
void gegl_op_noise_rgb_register_type(GTypeModule *module);
void gegl_op_noise_simplex_register_type(GTypeModule *module);
void gegl_op_noise_spread_register_type(GTypeModule *module);
void gegl_op_noise_cell_register_type(GTypeModule *module);
void gegl_op_opacity_register_type(GTypeModule *module);
void gegl_op_open_buffer_register_type(GTypeModule *module);
void gegl_op_over_register_type(GTypeModule *module);
void gegl_op_panorama_projection_register_type(GTypeModule *module);
void gegl_op_pixelize_register_type(GTypeModule *module);
void gegl_op_posterize_register_type(GTypeModule *module);
void gegl_op_radial_gradient_register_type(GTypeModule *module);
void gegl_op_rectangle_register_type(GTypeModule *module);
void gegl_op_recursive_transform_register_type(GTypeModule *module);
void gegl_op_reinhard05_register_type(GTypeModule *module);
void gegl_op_remap_register_type(GTypeModule *module);
void gegl_op_rgb_clip_register_type(GTypeModule *module);
void gegl_op_saturation_register_type(GTypeModule *module);
void gegl_op_save_register_type(GTypeModule *module);
void gegl_op_sepia_register_type(GTypeModule *module);
void gegl_op_slic_register_type(GTypeModule *module);
void gegl_op_snn_mean_register_type(GTypeModule *module);
void gegl_op_spherize_register_type(GTypeModule *module);
void gegl_op_stress_register_type(GTypeModule *module);
void gegl_op_stretch_contrast_hsv_register_type(GTypeModule *module);
void gegl_op_stretch_contrast_register_type(GTypeModule *module);
void gegl_op_svg_huerotate_register_type(GTypeModule *module);
void gegl_op_svg_luminancetoalpha_register_type(GTypeModule *module);
void gegl_op_svg_matrix_register_type(GTypeModule *module);
void gegl_op_svg_saturate_register_type(GTypeModule *module);
void gegl_op_threshold_register_type(GTypeModule *module);
void gegl_op_tile_register_type(GTypeModule *module);
void gegl_op_tile_seamless_register_type(GTypeModule *module);
void gegl_op_unsharp_mask_register_type(GTypeModule *module);
void gegl_op_unpremultiply_register_type(GTypeModule *module);
void gegl_op_value_invert_register_type(GTypeModule *module);
void gegl_op_vignette_register_type(GTypeModule *module);
void gegl_op_warp_register_type(GTypeModule *module);
void gegl_op_waterpixels_register_type(GTypeModule *module);
void gegl_op_watershed_transform_register_type(GTypeModule *module);
void gegl_op_wavelet_blur_1d_register_type(GTypeModule *module);
void gegl_op_wavelet_blur_register_type(GTypeModule *module);
void gegl_op_weighted_blend_register_type(GTypeModule *module);
void gegl_op_write_buffer_register_type(GTypeModule *module);
static const GeglModuleInfo modinfo = {
GEGL_MODULE_ABI_VERSION
};

const GeglModuleInfo * gegl_module_query (GTypeModule *module);
gboolean gegl_module_register (GTypeModule *module);

G_MODULE_EXPORT const GeglModuleInfo *
gegl_module_query (GTypeModule *module)
{
  return &modinfo;
}

G_MODULE_EXPORT gboolean
gegl_module_register (GTypeModule *module)
{
  gegl_op_absolute_register_type(module);
  gegl_op_alien_map_register_type(module);
  gegl_op_bilateral_filter_register_type(module);
  gegl_op_box_blur_register_type(module);
  gegl_op_brightness_contrast_register_type(module);
  gegl_op_buffer_sink_register_type(module);
  gegl_op_buffer_source_register_type(module);
  gegl_op_c2g_register_type(module);
  gegl_op_checkerboard_register_type(module);
  gegl_op_dither_register_type(module);
  gegl_op_color_enhance_register_type(module);
  gegl_op_color_overlay_register_type(module);
  gegl_op_color_rotate_register_type(module);
  gegl_op_color_temperature_register_type(module);
  gegl_op_color_warp_register_type(module);
  gegl_op_color_register_type(module);
  gegl_op_component_extract_register_type(module);
  gegl_op_contrast_curve_register_type(module);
  gegl_op_convolution_matrix_register_type(module);
  gegl_op_copy_buffer_register_type(module);
  gegl_op_difference_of_gaussians_register_type(module);
  gegl_op_display_register_type(module);
  gegl_op_distance_transform_register_type(module);
  gegl_op_dropshadow_register_type(module);
  gegl_op_edge_neon_register_type(module);
  gegl_op_edge_sobel_register_type(module);
  gegl_op_exp_combine_register_type(module);
  gegl_op_exposure_register_type(module);
  gegl_op_fattal02_register_type(module);
  gegl_op_gaussian_blur_register_type(module);
  gegl_op_gblur_1d_register_type(module);
  gegl_op_gegl_buffer_load_op_register_type(module);
  gegl_op_gegl_buffer_save_op_register_type(module);
  gegl_op_gegl_register_type(module);
  gegl_op_grey_register_type(module);
  gegl_op_grid_register_type(module);
  gegl_op_high_pass_register_type(module);
  gegl_op_hue_chroma_register_type(module);
  gegl_op_icc_save_register_type(module);
  gegl_op_image_compare_register_type(module);
  gegl_op_image_gradient_register_type(module);
  gegl_op_introspect_register_type(module);
  gegl_op_invert_gamma_register_type(module);
  gegl_op_invert_linear_register_type(module);
  gegl_op_layer_register_type(module);
  gegl_op_levels_register_type(module);
  gegl_op_linear_gradient_register_type(module);
  gegl_op_little_planet_register_type(module);
  gegl_op_long_shadow_register_type(module);
  gegl_op_magick_load_register_type(module);
  gegl_op_mantiuk06_register_type(module);
  gegl_op_map_absolute_register_type(module);
  gegl_op_map_relative_register_type(module);
  gegl_op_matting_global_register_type(module);
  gegl_op_mblur_register_type(module);
  gegl_op_mean_curvature_blur_register_type(module);
  gegl_op_median_blur_register_type(module);
  gegl_op_mirrors_register_type(module);
  gegl_op_mix_register_type(module);
  gegl_op_mono_mixer_register_type(module);
  gegl_op_motion_blur_linear_register_type(module);
  gegl_op_newsprint_register_type(module);
  gegl_op_noise_cie_lch_register_type(module);
  gegl_op_noise_hsv_register_type(module);
  gegl_op_noise_hurl_register_type(module);
  gegl_op_noise_perlin_register_type(module);
  gegl_op_noise_pick_register_type(module);
  gegl_op_noise_reduction_register_type(module);
  gegl_op_noise_rgb_register_type(module);
  gegl_op_noise_simplex_register_type(module);
  gegl_op_noise_spread_register_type(module);
  gegl_op_noise_cell_register_type(module);
  gegl_op_opacity_register_type(module);
  gegl_op_open_buffer_register_type(module);
  gegl_op_over_register_type(module);
  gegl_op_panorama_projection_register_type(module);
  gegl_op_pixelize_register_type(module);
  gegl_op_posterize_register_type(module);
  gegl_op_radial_gradient_register_type(module);
  gegl_op_rectangle_register_type(module);
  gegl_op_recursive_transform_register_type(module);
  gegl_op_reinhard05_register_type(module);
  gegl_op_remap_register_type(module);
  gegl_op_rgb_clip_register_type(module);
  gegl_op_saturation_register_type(module);
  gegl_op_save_register_type(module);
  gegl_op_sepia_register_type(module);
  gegl_op_slic_register_type(module);
  gegl_op_snn_mean_register_type(module);
  gegl_op_spherize_register_type(module);
  gegl_op_stress_register_type(module);
  gegl_op_stretch_contrast_hsv_register_type(module);
  gegl_op_stretch_contrast_register_type(module);
  gegl_op_svg_huerotate_register_type(module);
  gegl_op_svg_luminancetoalpha_register_type(module);
  gegl_op_svg_matrix_register_type(module);
  gegl_op_svg_saturate_register_type(module);
  gegl_op_threshold_register_type(module);
  gegl_op_tile_register_type(module);
  gegl_op_tile_seamless_register_type(module);
  gegl_op_unsharp_mask_register_type(module);
  gegl_op_unpremultiply_register_type(module);
  gegl_op_value_invert_register_type(module);
  gegl_op_vignette_register_type(module);
  gegl_op_warp_register_type(module);
  gegl_op_waterpixels_register_type(module);
  gegl_op_watershed_transform_register_type(module);
  gegl_op_wavelet_blur_1d_register_type(module);
  gegl_op_wavelet_blur_register_type(module);
  gegl_op_weighted_blend_register_type(module);
  gegl_op_write_buffer_register_type(module);
 return TRUE;
}
